==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dde-abrecovery/translations/dde-rollback_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
<context>
    <name>BackgroundWidget</name>
    <message>
        <source>Rolling back the system, please wait...</source>
        <translation>Het systeem wordt teruggerold - even geduld...</translation>
    </message>
</context>
<context>
    <name>RecoveryWidget</name>
    <message>
        <source>Rollback failed.</source>
        <translation>Het terugrollen is mislukt.</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Herstarten</translation>
    </message>
    <message>
        <source>Updates failed.</source>
        <translation>Updates mislukt.</translation>
    </message>
    <message>
        <source>Updates failed: it was interrupted.</source>
        <translation>Updates mislukt: proces onderbroken.</translation>
    </message>
    <message>
        <source>Updates failed: DPKG error.</source>
        <translation>Updates mislukt: DPKG-fout.</translation>
    </message>
    <message>
        <source>Updates failed: insufficient disk space.</source>
        <translation>Updates mislukt: onvoldoende vrije schijfruimte</translation>
    </message>
    <message>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>Weet je zeker dat je wilt terugrollen naar back-up %1 van %2?</translation>
    </message>
    <message>
        <source>Cancel and Reboot</source>
        <translation>Annuleren en herstarten</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Oké</translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.19.tar.xz: BUILD/src/dde-abrecovery/translations/dde-rollback_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>BackgroundWidget</name>
    <message>
        <source>Rolling back the system, please wait...</source>
        <translation>Het systeem wordt teruggerold - even geduld...</translation>
    </message>
</context>
<context>
    <name>RecoveryWidget</name>
    <message>
        <source>Rollback failed.</source>
        <translation>Het terugrollen is mislukt.</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Herstarten</translation>
    </message>
    <message>
        <source>Updates failed.</source>
        <translation>Updates mislukt.</translation>
    </message>
    <message>
        <source>Updates failed: it was interrupted.</source>
        <translation>Updates mislukt: proces onderbroken.</translation>
    </message>
    <message>
        <source>Updates failed: DPKG error.</source>
        <translation>Updates mislukt: DPKG-fout.</translation>
    </message>
    <message>
        <source>Updates failed: insufficient disk space.</source>
        <translation>Updates mislukt: onvoldoende vrije schijfruimte</translation>
    </message>
    <message>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>Weet je zeker dat je wilt terugrollen naar back-up %1 van %2?</translation>
    </message>
    <message>
        <source>Cancel and Reboot</source>
        <translation>Annuleren en herstarten</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Oké</translation>
    </message>
</context>
</TS>
